@@ -93,6 +93,7 @@ mock_node_uuid = str(uuid4_from_hash(MockNode.__qualname__))
                     "display_context": None,
                     "initial_state": None,
                     "workflow_version_exec_config": None,
+                    "server_metadata": None,
                 },
                 "parent": None,
                 "links": None,
@@ -227,6 +228,47 @@ mock_node_uuid = str(uuid4_from_hash(MockNode.__qualname__))
                     "outputs": {
                         "example": "foo",
                     },
+                    "final_state": None,
+                    "server_metadata": None,
+                },
+                "parent": None,
+                "links": None,
+            },
+        ),
+        (
+            WorkflowExecutionFulfilledEvent(
+                id=UUID("123e4567-e89b-12d3-a456-426614174000"),
+                timestamp=datetime(2024, 1, 1, 12, 0, 0, tzinfo=timezone.utc),
+                trace_id=UUID("123e4567-e89b-12d3-a456-426614174000"),
+                span_id=UUID("123e4567-e89b-12d3-a456-426614174000"),
+                body=WorkflowExecutionFulfilledBody(
+                    workflow_definition=MockWorkflow,
+                    outputs=MockNode.Outputs(
+                        example="foo",
+                    ),
+                    final_state=BaseState(writable_value=42),
+                ),
+            ),
+            {
+                "id": "123e4567-e89b-12d3-a456-426614174000",
+                "api_version": "2024-10-25",
+                "timestamp": "2024-01-01T12:00:00Z",
+                "trace_id": "123e4567-e89b-12d3-a456-426614174000",
+                "span_id": "123e4567-e89b-12d3-a456-426614174000",
+                "name": "workflow.execution.fulfilled",
+                "body": {
+                    "workflow_definition": {
+                        "id": mock_workflow_uuid,
+                        "name": "MockWorkflow",
+                        "module": module_root + ["events", "tests", "test_event"],
+                    },
+                    "outputs": {
+                        "example": "foo",
+                    },
+                    "final_state": {
+                        "writable_value": 42,
+                    },
+                    "server_metadata": None,
                 },
                 "parent": None,
                 "links": None,
@@ -263,6 +305,7 @@ mock_node_uuid = str(uuid4_from_hash(MockNode.__qualname__))
                         "message": "Workflow failed",
                         "code": "USER_DEFINED_ERROR",
                         "raw_data": None,
+                        "stacktrace": None,
                     },
                     "stacktrace": None,
                 },
@@ -426,6 +469,7 @@ mock_node_uuid = str(uuid4_from_hash(MockNode.__qualname__))
         "node.execution.initiated",
         "workflow.execution.streaming",
         "workflow.execution.fulfilled",
+        "workflow.execution.fulfilled_with_state",
         "workflow.execution.rejected",
         "node.execution.streaming",
         "node.execution.fulfilled",
